UiPath Documentation
automation-suite
2.2510
true
guide de référence uipathctl
Important :
Veuillez noter que ce contenu a été localisé en partie à l’aide de la traduction automatique. La localisation du contenu nouvellement publié peut prendre 1 à 2 semaines avant d’être disponible.

uipathctl config token-signing-certificates update

Mettez à jour le futur certificat de signature de jetons dans Automation Suite.

Description​

Mettez à jour le futur certificat de signature de jetons en fournissant pfx et key comme arguments.

Si la clé fournie est chiffrée, utilisez l'indicateur --password spécifiant le mot de passe de déchiffrement.

La commande utilise par défaut le contexte actuel dans le fichier kubeconfig . Si l'indicateur --kubeconfig est défini, il utilise le fichier kubeconfig spécifié par l'indicateur.

uipathctl config token-signing-certificates update [flags]
uipathctl config token-signing-certificates update [flags]

Exemples​

# Update the token signing certificate with the provided certificate path and key path from the cluster
uipathctl config token-signing-certificates update --cert server.crt --key server.key

# Update the token signing certificate with the provided certificate path and encrypted key path from the cluster
uipathctl config token-signing-certificates update --cert server.crt --key server.key --password password

# Update the token signing certificate with the provided certificate path and key path from the cluster identified by the current context in the kubeconfig file
uipathctl config token-signing-certificates update --cert server.crt --key server.key --kubeconfig cluster.kubeconfig

# Update the token signing certificate with the provided pfx certificate
uipathctl config tls-certificates update --pfx-cert certificate.pfx --password password
# Update the token signing certificate with the provided certificate path and key path from the cluster
uipathctl config token-signing-certificates update --cert server.crt --key server.key

# Update the token signing certificate with the provided certificate path and encrypted key path from the cluster
uipathctl config token-signing-certificates update --cert server.crt --key server.key --password password

# Update the token signing certificate with the provided certificate path and key path from the cluster identified by the current context in the kubeconfig file
uipathctl config token-signing-certificates update --cert server.crt --key server.key --kubeconfig cluster.kubeconfig

# Update the token signing certificate with the provided pfx certificate
uipathctl config tls-certificates update --pfx-cert certificate.pfx --password password

Options​

      --cert string       path to certificate
  -h, --help              help for update
      --key string        path to certificate key
      --password string   password for encrypted key
      --pfx-cert string   path to certificate in pfx format
      --namespace string   The namespace where UiPath Automation Suite is deployed (default "uipath")
      --cert string       path to certificate
  -h, --help              help for update
      --key string        path to certificate key
      --password string   password for encrypted key
      --pfx-cert string   path to certificate in pfx format
      --namespace string   The namespace where UiPath Automation Suite is deployed (default "uipath")

Options héritées des commandes parent​

      --context string      name of the kubeconfig context to use
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-format string   log format. one of [text,json] (default "text")
      --log-level string    set log level. one of [trace,debug,info,error] (default "info")
  -q, --quiet               suppress all output except for errors and warnings
      --timeout duration    timeout of the command (default: 90 minutes) (default 1h30m0s)
      --context string      name of the kubeconfig context to use
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-format string   log format. one of [text,json] (default "text")
      --log-level string    set log level. one of [trace,debug,info,error] (default "info")
  -q, --quiet               suppress all output except for errors and warnings
      --timeout duration    timeout of the command (default: 90 minutes) (default 1h30m0s)
  • Description​
  • Exemples​
  • Options​
  • Options héritées des commandes parent​

Cette page vous a-t-elle été utile ?

Connecter

Besoin d'aide ? Assistance

Vous souhaitez apprendre ? UiPath Academy

Vous avez des questions ? UiPath Forum

Rester à jour